<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        :paramArr="type"
        ref="reserveMainTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {delObj, fetchList} from '@/api/warehouse/reservemain'
  import TableForm from './reservemain-form'
  import {mapGetters} from 'vuex'
  import ttable from '@/views/common/ztt-table.vue';
  import {loadStockInCode} from "../../../api/warehouse/stockincode";
  import {loadFactoryList} from "../../../api/basic/factory";

  export default {
    data () {
      return {
        factoryOptions:[],
        type:[1],
        ajaxFun:fetchList,
        resTypeOptions:[],
        mulPrepareList: [],
        isShowQuery:false,
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        prelang:"operation",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:true,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'resDate',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //领料号
            {minWidth:'140',prop:"resNo",label:"领料号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',render:{fun:this.addOrUpdateHandle}},
            //申请日期
            {minWidth:'120',width:'200',prop: "resDate",label:"申请日期",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange'},
            //申请人
            {minWidth:'200',prop: "resUser",label:"申请人",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //工厂
            {minWidth:'140',prop:"factoryId",label:"工厂",sort: true,isTrue:true,isSearch:false,searchInfoType:'text',formatter:this.getReserveFactory,optList:() => {return this.factoryOptions}},
            //出库类型
            {minWidth:'120',prop: "resType",label:"出库类型",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',formatter:this.resTypeType,optList:() => {return this.getResTypeOptionList()}},
            //状态
            {minWidth:'200',prop: "resStatus",label:"状态",sort: true,isTrue:true,isSearch:false,searchInfoType:'text',formatter:this.getResStatus,optList:() => {return this.getResStatusOptionList()}},
          ],
          toolbar: [
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:100,
            minWidth:100
          },
        },
        addOrUpdateVisible: false,
        ResStatusOptionList:[
          {
            value:'05create',
            label:'创建中'
          },
          {
            value:'06perform',
            label:'执行中'
          },
          {
            value:'07handle',
            label:'已处理'
          }
        ]
      }
    },
    components: {
      ttable,
      TableForm
    },
    created () {
      this.initStockInCodeSelect()
      this.initFactorySelect()
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      getResStatusOptionList(){
        return this.ResStatusOptionList;
      },
      getResStatus(row, column, cellValue){
          this.ResStatusOptionList.forEach(obj => {
            if (obj.value == cellValue) {
              cellValue = obj.label
              return
            }
          })
          return cellValue
      },
      // 获取工厂的数据
      initFactorySelect() {
        loadFactoryList().then(res => {
          this.factoryOptions = JSON.parse(JSON.stringify(res.data).replace(/id/g, 'value').replace(/factoryName/g, 'label'));
        })
      },
      getReserveFactory(row, column, cellValue){
        this.factoryOptions.forEach(obj => {
          if (obj.value == cellValue) {
            cellValue = obj.label
            return
          }
        })
        return cellValue
      },
      //选中行
      handleSelectionChange(val) {
        this.mulPrepareList = val
      },
      getResTypeOptionList(){
        return this.resTypeOptions
      },
      //将id进行匹配显示为对应的出库类型描述
      resTypeType(row, column, cellValue){
        this.resTypeOptions.forEach(obj => {
          if (obj.value == cellValue) {
            cellValue = obj.label
            return
          }
        })
        return cellValue
      },
      // 获取出入库原因码的数据
      initStockInCodeSelect() {
        loadStockInCode(Object.assign(
          {
            stockCodeType : 1,
            stockCodeStatus : 1
          }
        )).then(res => {
          this.resTypeOptions = JSON.parse(JSON.stringify(res.data.data).replace(/id/g, 'value').replace(/stockCodeName/g, 'label'));
        })
      },
      // 获取数据列表
      getData () {
        this.$refs.reserveMainTable.getDataList();
      },
      getLocationStatusOptionList(){
        return this.locationOptionList;
      },
      // 新增 / 修改
      addOrUpdateHandle(row) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row==null?null:row.id)
        })
      },
      // 删除
      deleteHandle (row) {
        this.$confirm('是否确认删除申请编号为' + row.resNo, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      }
    }
  }
</script>
